@@ -22,20 +22,22 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 '''
 
-import os
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import List, Optional
 
-from .. import os_utils
-from .base_target import BuildTarget
-
-StrOrPath = Union[str, Path]
+from buildtools import os_utils
+from buildtools.maestro.base_target import BuildTarget
+from buildtools.types import StrOrPath
 
 
 class RonnBuildTarget(BuildTarget):
     BT_LABEL = 'RONN'
 
-    def __init__(self, markdown_filename: StrOrPath, section: int = 1, dependencies: List[str] = [], ronn_executable: Optional[StrOrPath] = None):
+    def __init__(self,
+                 markdown_filename: StrOrPath,
+                 section: int = 1,
+                 dependencies: List[str] = [],
+                 ronn_executable: Optional[StrOrPath] = None) -> None:
         self.markdown_filename: Path = Path(markdown_filename)
         self.section: int = section
         self.dependencies: List[str] = dependencies
@@ -45,7 +47,9 @@ class RonnBuildTarget(BuildTarget):
         self.output_roff_filename: Path = self.markdown_filename.with_suffix('')
         self.output_html_filename: Path = self.markdown_filename.with_suffix('.html')
         self.output_markdown_filename: Path = self.markdown_filename.with_suffix('.markdown')
-        super().__init__(targets=[str(self.output_roff_filename), str(self.output_html_filename), str(self.output_markdown_filename)],
+        super().__init__(targets=[str(self.output_roff_filename),
+                                  str(self.output_html_filename),
+                                  str(self.output_markdown_filename)],
                          files=[str(markdown_filename)],
                          dependencies=dependencies)
 
